# Toast Notification REST Client

Toast cloud Notification RESTful API Client for Python User.

- Not supported SLA
- Current only supported SMS/MMS yet
- Default REST API Version is V2.2


## Install

```py
pip install toast-notification-client
```

## Function

### Initalize

```python
from toast import ToastSMS
tos = ToastSMS("<API-KEY>")
```